"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decorateCompletions = void 0;
const utils_1 = require("../utils");
const componentPostfix = '__SvelteComponent_';
function decorateCompletions(ls, logger) {
    const getCompletionsAtPosition = ls.getCompletionsAtPosition;
    ls.getCompletionsAtPosition = (fileName, position, options) => {
        const completions = getCompletionsAtPosition(fileName, position, options);
        if (!completions) {
            return completions;
        }
        return {
            ...completions,
            entries: completions.entries.map((entry) => {
                if (!(0, utils_1.isSvelteFilePath)(entry.source || '') ||
                    !entry.name.endsWith(componentPostfix)) {
                    return entry;
                }
                return {
                    ...entry,
                    name: entry.name.slice(0, -componentPostfix.length)
                };
            })
        };
    };
    const getCompletionEntryDetails = ls.getCompletionEntryDetails;
    ls.getCompletionEntryDetails = (fileName, position, entryName, formatOptions, source, preferences, data) => {
        const details = getCompletionEntryDetails(fileName, position, entryName, formatOptions, source, preferences, data);
        if (details) {
            if ((0, utils_1.isSvelteFilePath)(source || '')) {
                logger.debug('TS found Svelte Component import completion details');
                return (0, utils_1.replaceDeep)(details, componentPostfix, '');
            }
            else {
                return details;
            }
        }
        if (!(0, utils_1.isSvelteFilePath)(source || '')) {
            return details;
        }
        // In the completion list we removed the component postfix. Internally,
        // the language service saved the list with the postfix, so details
        // won't match anything. Therefore add it back and remove it afterwards again.
        const svelteDetails = getCompletionEntryDetails(fileName, position, entryName + componentPostfix, formatOptions, source, preferences, data);
        if (!svelteDetails) {
            return undefined;
        }
        logger.debug('Found Svelte Component import completion details');
        return (0, utils_1.replaceDeep)(svelteDetails, componentPostfix, '');
    };
}
exports.decorateCompletions = decorateCompletions;
//# sourceMappingURL=completions.js.map